pro sot_dsc_par1, table_name, orbit_file = orbit_file

;+
; NAME:
;       SOT_DSC_PAR1.PRO
;
; PURPOSE:
;       Read orbital element data & Make an Doppler table 
;
; CALLING SEQUENCE:
;       sot_dsc_par1, table_name [,orbit_file = orbit_file] 
;
; INPUTS:
;       table_name -- file name of Doppler table (MDPDPL-yyyymmddpppp.xml) 
;
; KEYWORD PARAMETERS:
;       orbit_file -- file name of orbital element
;                     [default: '~cp/cmdpln/data/orbit_dsc/orbit_dsc.data']
; OUTPUTS:
;       MDPDPL-yyyymmddpppp.xml
; 
;
; MODIFICATION HISTORY:
;       05-Jul-2006 - Made by M.Kubo
;
;-

dpltbl_dir ='~sotco/mdp_dsc/ObsTbl/'
dsc_par1_dir = '~sotco/mdp_dsc/orl/par1/'
dpllog ='~sotco/mdp_dsc/log/par1/DSC_par1.log'


if n_elements(orbit_file) eq 0 then $
  orbit_file ='/sotcp/cp/cmdpln/data/orbit_dsc/orbit_dsc.data'

;;; Satellite Revolution
vsat = sot_dsc_vsat(orbit_file, oe = oe)

;;; Earth Revolution
veth = sot_dsc_vearth(oe.time)


;;; Read RAMsub# from log file
tmp=''
if 1 - (file_info(dpllog)).exists then begin 
    openw, lunit, dpllog, /get_lun
    printf, lunit, 'MDPDPL-yyyymmddpppp.xml' + ' ' + ' OE#' + ' ' + 'RAM#' 
    ram = 271
endif else begin
    openu, lunit, dpllog, /get_lun
    while 1 - EOF(lunit) dO begin 
        readf, lunit, tmp
    endwhile
    ram = fix(strmid(tmp,30,3)) + 1
    if ram ge 280 then ram = 271
endelse


;;; Make Doppler table (.xml file)
openw,tunit,dpltbl_dir + table_name,/get_lun
printf,tunit,'<?xml version="1.0" encoding="UTF-8"?>'
printf,tunit,'<!DOCTYPE DOPL_TBL SYSTEM "MDPDPL.dtd">'
printf,tunit,'<DOPL_TBL>'
;printf,tunit,'  <RAMSUB_NO>0x'+string(ulong(ram), $
;                                      format='(Z8.8)')+'</RAMSUB_NO>'
printf,tunit,'  <T0>0x'+string(ulong(vsat.T0)/2D^(-9),format='(Z8.8)')+'</T0>'
printf,tunit,'  <V0>0x'+string(long(vsat.V0*10D^3/86400D),$
                               format='(Z8.8)')+'</V0>'
printf,tunit,'  <V1>0x'+string(long(vsat.V1*10D^3/86400D^2/2D^(-20)),$
                               format='(Z8.8)')+'</V1>'
printf,tunit,'  <V2>0x'+string(long(vsat.V2*10D^3/86400D^3/2D^(-40)),$
                               format='(Z8.8)')+'</V2>'
printf,tunit,'  <U0>0x'+string(long(vsat.U0*10D^3/86400D),$
                               format='(Z8.8)')+'</U0>'
printf,tunit,'  <U1>0x'+string(long(vsat.U1*10D^3/86400D^2/2D^(-20)),$
                               format='(Z8.8)')+'</U1>'
printf,tunit,'  <U2>0x'+string(long(vsat.U2*10D^3/86400D^3/2D^(-40)),$
                               format='(Z8.8)')+'</U2>'
printf,tunit,'  <A0>0x'+string(long(vsat.A0/(2D^(-31)*!dpi)),$
                              format='(Z8.8)')+'</A0>'
printf,tunit,'  <A1>0x'+string(long(vsat.A1/(2D^(-31)*!dpi)),$
                              format='(Z8.8)')+'</A1>'
printf,tunit,'  <A2>0x'+string(long(vsat.A2/(2D^(-31)*!dpi)),$
                              format='(Z8.8)')+'</A2>'
printf,tunit,'  <B0>0x'+string(long(vsat.B0/(2D^(-31)*!dpi)),$
                               format='(Z8.8)')+'</B0>'
printf,tunit,'  <B1>0x'+string(long(vsat.B1/(2D^(-31)*!dpi)),$
                               format='(Z8.8)')+'</B1>'
printf,tunit,'  <B2>0x'+string(long(vsat.B2/(2D^(-31)*!dpi)),$
                               format='(Z8.8)')+'</B2>'
printf,tunit,'  <e0>0x'+string(long(vsat.E/2D^(-32)),$
                               format='(Z8.8)')+'</e0>'
printf,tunit,'  <Veth0>0x'+string(long(veth.eth0*10D^3/86400D),$
                                  format='(Z8.8)')+'</Veth0>'
printf,tunit,'  <Veth1>0x'+string(long(veth.eth1*10D^3/86400D^2/2D^(-20)),$
                                  format='(Z8.8)')+'</Veth1>'
printf,tunit,'</DOPL_TBL>'

free_lun, tunit


;;;; Make table upload & par1_update command (.orl file)
;dsc_par1_orl ='MDPDSC' + strmid(uptime,0,4) + strmid(uptime,5,2) + $
;  strmid(uptime,8,2) + string(passID,format='(I2.2)')+'.orl'
;
;openw,ounit, dsc_par1_dir + dsc_par1_orl,/get_lun
;printf,ounit,'/* Real-time sequence execution */'
;printf,ounit,'START : ' + uptime + ' {SEQ : MDP_DSC_PAR1_UPDATE_SEQ; }'
;
;printf,ounit,''
;printf,ounit,'/* ----------------------------------------------------------------- */'
;printf,ounit,'/* Rela Sequences */'
;printf,ounit,'DEFSEQ(REAL) : MDP_DSC_PAR1_UPDATE_SEQ{'
;printf,ounit,'      CMD:MDP_DUMP_FGTBL 00 38 B8 00 40;'
;printf,ounit,'      ENTRY: RAM MDP_DPL ' + string(ram, format='(I3)') + $
;  ' ' + string(ram, format='(I3)') + ';'
;printf,ounit,'      CMD:MDP_DUMP_FGTBL 00 38 B8 00 40;'
;printf,ounit,'      CMD:MDP_DSC_PAR1_UPDATE;'
;printf,ounit,'}'
;
;free_lun, ounit


;;; Update log file
printf, lunit, string(table_name, format='(A23)')+ ' ' + $
  string(oe.no, format='(I4)') + '  ' + string(ram, format='(I3)')
free_lun, lunit

end

