pro sot_dsc_par2, filename

;+
; NAME:
;       SOT_DSC_PAR2.PRO
;
; PURPOSE:
;       Read an AOCS re-pointing file & Make an ORL file including
;        comannd sequences of "MDP_DSC_PAR2_UPDATE"
;
; CALLING SEQUENCE:
;       sot_dsc_par2, filename 
;
; INPUTS:
;       filename -- filename of re-pointing file (re-point_yyyymmddpppp.txt)
;
; OUTPUTS:
;       MDPDSC_yyyymmddpppp.orl
; 
;
; MODIFICATION HISTORY:
;       05-Jul-2006 - Made by M.Kubo
;
;-


dsc_par2_dir = '~sotco/mdp_dsc/orl/par2/'

;;; Sun Rotation
vsun = sot_dsc_vsun('/sotcp/cp/cmdpln/latest/' + filename)

st = strpos(filename, 're-point_') + 9 
ed = strpos(filename, '.txt') - 1

 
;;; Make par2_update parameters
n = n_elements(vsun)
SEQ = strarr(n)
OG = strarr(n)
CMD = strarr(n)
sL1 = strmid(string(long(vsun.L1/(2D^(-31)*!dpi)),$
                    format='(Z8.8)'),2*indgen(4),2)
sOm = strmid(string(long(vsun.Omega/(2D^(-31)*!dpi)),$
                    format='(Z8.8)'),2*indgen(4),2)
sPh = strmid(string(long(vsun.Phi*10D^3),$
                    format='(Z8.8)'),2*indgen(4),2)

for i=0,n-1 do begin
    seq[i] = 'MDP_DSC_PAR2_UPDATE_' + string(i+1,format='(i2.2)')+'_SEQ'
    OG[i] = 'MDP_DSC_PAR2_UPDATE_' + string(i+1,format='(i2.2)')+'_OG'

    param = ''
    for j=0,3 do param = param + ' ' + sL1[j,i]
    for j=0,3 do param = param + ' ' + sOm[j,i]
    for j=0,3 do param = param + ' ' + sPh[j,i]

    CMD[i] = 'MDP_DSC_PAR2_UPDATE' + param
endfor


;;; Make par2_update command (.orl file)
dsc_par2_orl ='MDPDSC_'+ strmid(filename,st, ed-st+1) + '.orl'

openw,unit,dsc_par2_dir + dsc_par2_orl,/get_lun
printf,unit,'/* OP sequence execution */'
for i=0,n-1 do printf,unit,'START : ' + vsun[i].TI + ' {SEQ : '+SEQ[i]+' ; }'

printf,unit,''
printf,unit,'/* ----------------------------------------------------------------- */'
printf,unit,'/* OP Sequences */'
for i=0,n-1 do begin
    printf,unit,'DEFSEQ(OP) : '+SEQ[i]+'{'
    printf,unit,'      OG : '+ OG[i] +' ;'
    printf,unit,'}'
    printf,unit,''
    printf,unit,''
endfor

printf,unit,'/* ----------------------------------------------------------------- */'
printf,unit,'/* OG Sequences */'
for i=0,n-1 do begin
    printf,unit,'DEFSEQ(OG) : '+OG[i]+'{'
    printf,unit,'      NUMBER : '+ string(i+390,format='(I3.3)') +' ;'
    printf,unit,'      CMD : '+ CMD[i]+' ;'
    printf,unit,'}'
endfor

free_lun, unit

end

