function sot_dsc_vearth, time

;+
; NAME:
;       SOT_DSC_VEARTH.PRO
;
; PURPOSE:
;       Calculate Doppler shift compensation 
;         againt Earth Revolution at a given time
;    
; CALLING SEQUENCE:
;       vearth = sot_dsc_vearth(time) 
;
; INPUTS:
;       time --  "yyyymmdd hh:mm:ss"
;
; OUTPUTS:
;       vsearth -- MDP parameters for earth revolution compensation 
; 
;
; MODIFICATION HISTORY:
;       05-Jul-2006 - Made by M.Kubo
;
;-


Te = 365.24219D
Ae = 1.49597870D*10D^8
Ee = 0.0167D
dtor = !dpi/180D

vearth = create_struct('eth0', 0D, 'eth1', 0D)


;;;;;; Julian day
jd = JULDAY(strmid(time,5,2), $  ; Month
            strmid(time,8,2), $  ; Day
            strmid(time,0,4), $  ; Year
            strmid(time,11,2), $ ; Hour
            strmid(time,14,2), $ ; Minute
            strmid(time,17,2))   ; Second



;;; Earth' mean anomaly
; me = 189.189 @2004/7/14.0 (Chronological Sciengific Tables) 
me = 189.189D + 360D/365.25964D*( JD - 2453200.5D )

;;; Earth Revolusion
vearth.eth0 = -(2D*!dpi/Te)*Ae*Ee*(sin(me*dtor) + Ee*sin(2D*me*dtor))
vearth.eth1 = -(2D*!dpi/Te)^2*Ae*Ee*(cos(me*!dtor) + Ee*(-1 + cos(2D*me*dtor)))

return, vearth

end

