function sot_dsc_vsat, filename, oe = oe 

;+
; NAME:
;       SOT_DSC_VSAT.PRO
;
; PURPOSE:
;       Read orbital element data & Calculate Doppler shift
;       compensation againt Satellite Revolution
;
; CALLING SEQUENCE:
;       vsat = sot_dsc_vsun(filename, [oe = oe]) 
;
; INPUTS:
;       filename --  file name of orbital element 
;
; OUTPUTS:
;       vsat -- MDP parameters for satellite revolution compensation 
; 
; OUTPUT KEYWORDS:
;       oe -- orbital element structure
;
; MODIFICATION HISTORY:
;       05-Jul-2006 - Made by M.Kubo
;
;-


;;; MDP Doppler Shift compensation (parmeter 1)
vsat = create_struct('T0', 0L, 'V0', 0D, 'V1', 0D, 'V2', 0D, 'U0', 0D, $
                     'U1', 0D, 'U2', 0D, 'A0', 0D, 'A1', 0D, 'A2', 0D, $
                     'B0', 0D, 'B1', 0D, 'B2', 0D, 'E', 0D)

;;; read orbital element
oe = sot_dsc_read_orbit(filename)
vsat.E = oe.E

;;; calculate mv 
mv = 2D*!dpi*oe.A/oe.P

;;; 1st order differential of mv and MA
dmv = (2D*!dpi*oe.A/oe.P)*(oe.dA/oe.A - oe.dP/oe.P) 
dMA = (2D*!dpi*oe.A/oe.P) 


;;; Satellite Revolusion
vsat.V0 = -mv*cos(oe.BET)*cos(oe.GAM)
vsat.V1 = -dmv*cos(oe.BET)*cos(oe.GAM) + $
  oe.dBET*mv*sin(oe.BET)*cos(oe.GAM) + oe.dGAM*mv*cos(oe.BET)*sin(oe.GAM)
vsat.V2 = 0

vsat.U0 = -mv*cos(oe.BET)*sin(oe.GAM)
vsat.U1 = -dmv*cos(oe.BET)*cos(oe.GAM) + $
  oe.dBET*mv*sin(oe.BET)*sin(oe.GAM) - oe.dGAM*mv*cos(oe.BET)*cos(oe.GAM)
vsat.U2 = 0

vsat.A0 = oe.MA + oe.AP
vsat.A1 = dMA + oe.dAP
vsat.A2 = 0

vsat.B0 = 2D*oe.MA + oe.AP
vsat.B1 = 2D*dMA + oe.dAP
vsat.B2 = 0

;;; T0
vsat.T0 = sot_dsc_t0(oe.time)


return, vsat
end

