function sot_dsc_vsun, filename


;+
; NAME:
;       SOT_DSC_VSUN.PRO
;
; PURPOSE:
;       Read an AOCS re-pointing file & Calculate Doppler shift
;       compensation againt Solar Rotation
;
; CALLING SEQUENCE:
;       vsun = sot_dsc_vsun(filename) 
;
; INPUTS:
;       filename -- filename of re-pointing file (re-point_yyyymmddpppp.txt)
;
; OUTPUTS:
;       vsun -- MDP parameters for solar ratation compensation 
; 
;
; MODIFICATION HISTORY:
;       05-Jul-2006 - Made by M.Kubo
;
;-

dtor = !dpi/180D
au = 1.49597870D*10D^8 ;km


;;; read pointing information
pt = sot_dsc_read_pointing(filename)
num = n_elements(pt)

;;; caluculate B0 angle
B0 = get_rb0p(pt.time, /b0angle)
R1 = au*tan(get_rb0p(pt.time, /radius)/3600D*dtor)*(get_sun(pt.time))[0]


;;; MDP Doppler Shift compensation (parmeter 2)
vsun = replicate(create_struct('TI', '', 'L1', 0D, 'Omega', 0D, 'Phi', 0D),num)
vsun.TI = strmid(pt.time,0,10)+'.'+strmid(pt.time,11,8)

;;; Solar Rotaion
vsun.Omega = (14.368D - 2.69D*(sin(pt.lat))^2 - $
              360D/365.244D)*dtor/(24D*60D*60D)
vsun.L1 = pt.lon
vsun.Phi = R1*vsun.Omega*cos(pt.lat)*cos(B0)

;;; No tracking
xx = where(pt.trak eq 0, xxnum)
if xxnum ne 0 then vsun[xx].Omega = 0

return, vsun

end

